# fakeitmakeit
[Marijan Beg](https://github.com/marijanbeg)<sup>1</sup>

<sup>1</sup> *Department of Earth Science and Engineering, Imperial College London, London SW7 2AZ, UK*  

## About

`fakeitmakeit` is a Python package designed for generating fake student data for testing purposes. This package is for developers who need realistic, but fictional, student data to test other packages without risking leaking the real student information. It can generate details such as student names, emails, nationalities, usernames, marks, and other information.

## Installation

You can install `fakeitmakeit` via `pip` from PyPI:

```bash
pip install fakeitmakeit
```

## Documentation

TBC (for now, refer to docstrings...)

## Support

If you require support, have questions, want to report a bug, or want to suggest an improvement, please raise an issue in this repository.

## Contributions

All contributions are welcome, however small they are. If you would like to contribute, please fork the repository and create a pull request. If you are not sure how to contribute, please contact us by raising an issue in this repository, and we are going to help you get started and assist you on the way.

## License

Licensed under the MIT License. For details, please refer to the [LICENSE](LICENSE) file.